class apt_pg {
  file { '/etc/apt/sources.list.d/pg.list':
    ensure  => present,
    content => 'deb http://pgapt.debian.net/ squeeze-pgdg main'
  }

  exec { 'pgpubkey':
    command     => '/usr/bin/wget http://pgapt.debian.net/ACCC4CF8.asc -O /tmp/pgapt.asc',
    subscribe   => File['/etc/apt/sources.list.d/pg.list'],
    refreshonly => true
  }

  exec { 'pgaddkey':
    command     => '/usr/bin/apt-key add /tmp/pgapt.asc',
    subscribe   => Exec['pgpubkey'],
    refreshonly => true
  }

  exec { 'updateapt':
    command     => '/usr/bin/apt-get update',
    subscribe   => Exec['pgaddkey'],
    refreshonly => true
  }
  
  file { '/etc/apt/preferences.d/pgdg':
    ensure      => present,
    content     => "Package: *\nPin: release a=squeeze-pgdg\nPin-Priority: 1000"
  }
} 

class pg_server { 

  include apt_pg
  Class['apt_pg'] -> Class['pg_server']

  package { 'libpq5':
    ensure  => '9.2.1-1.pgdg60+1'
  }

  package { 'postgresql-contrib-9.2':
    ensure  => present,
    require => Package['libpq5']
  }
  
  file { '/var/lib/postgresql/.ssh':
    ensure  => directory,
    owner   => postgres,
    group   => postgres,
    require => Package['postgresql-contrib-9.2'],
    mode    => '0700'
  }
  file { '/var/lib/postgresql/.ssh/id_rsa':
    ensure  => present,
    owner   => postgres,
    group   => postgres,
    mode    => '0600',
    require => File['/var/lib/postgresql/.ssh'],
    source  => 'puppet:///files/pg'
  }
  file { '/var/lib/postgresql/.ssh/id_rsa.pub':
    ensure  => present,
    owner   => postgres,
    group   => postgres,
    mode    => '0600',
    require => File['/var/lib/postgresql/.ssh'],
    source  => 'puppet:///files/pg.pub'
  }
  file { '/var/lib/postgresql/.ssh/authorized_keys':
    ensure  => present,
    owner   => postgres,
    group   => postgres,
    mode    => '0600',
    require => File['/var/lib/postgresql/.ssh'],
    source  => 'puppet:///files/bm.pub'
  }
  file { '/var/lib/postgresql/.ssh/config':
    ensure  => present,
    owner   => postgres,
    group   => postgres,
    mode    => '0600',
    require => File['/var/lib/postgresql/.ssh'],
    content => 'StrictHostKeyChecking no'
  }

  file { '/etc/postgresql/9.2/main/pg_hba.conf':
    ensure  => present,
    owner   => postgres,
    group   => postgres,
    mode    => '0644',
    require => File['/var/lib/postgresql/.ssh/id_rsa'],
    source  => 'puppet:///files/pg_hba.conf'
  }
  file { '/etc/postgresql/9.2/main/postgresql.conf':
    ensure  => present,
    owner   => postgres,
    group   => postgres,
    mode    => '0644',
    require => File['/var/lib/postgresql/.ssh/id_rsa'],
    source  => 'puppet:///files/postgresql.conf'
  }
  exec { 'pg-restart':
    command => '/usr/sbin/service postgresql restart',
    subscribe => File[ '/etc/postgresql/9.2/main/postgresql.conf' ],
    refreshonly => true
  }
  exec { 'pg-reload':
    command => '/usr/sbin/service postgresql reload',
    subscribe => File[ '/etc/postgresql/9.2/main/pg_hba.conf' ],
    refreshonly => true
  }
}

class pg_barman { 

  include apt_pg
  Class['apt_pg'] -> Class['pg_barman']

  package { 'barman':
    ensure  => present
  }

  file { '/var/lib/barman/.ssh':
    ensure  => directory,
    owner   => barman,
    group   => barman,
    require => Package['barman'],
    mode    => '0700'
  }
  file { '/var/lib/barman/.ssh/id_rsa':
    ensure  => present,
    owner   => barman,
    group   => barman,
    mode    => '0600',
    require => File['/var/lib/barman/.ssh'],
    source  => 'puppet:///files/bm'
  }
  file { '/var/lib/barman/.ssh/id_rsa.pub':
    ensure  => present,
    owner   => barman,
    group   => barman,
    mode    => '0600',
    require => File['/var/lib/barman/.ssh'],
    source  => 'puppet:///files/bm.pub'
  }
  file { '/var/lib/barman/.ssh/authorized_keys':
    ensure  => present,
    owner   => barman,
    group   => barman,
    mode    => '0600',
    require => File['/var/lib/barman/.ssh'],
    source  => 'puppet:///files/pg.pub'
  }
  file { '/var/lib/barman/.ssh/config':
    ensure  => present,
    owner   => barman,
    group   => barman,
    mode    => '0600',
    require => File['/var/lib/barman/.ssh'],
    content => 'StrictHostKeyChecking no'
  }

}

node pg {
  include pg_server
}
node pg_recovery {
  include pg_server
}
node bm {
  include pg_barman
}
